aboutsummaryrefslogtreecommitdiffhomepage
diff options
context:
space:
mode:
authorGravatar David Aspinall <da@inf.ed.ac.uk>1999-10-21 16:37:43 +0000
committerGravatar David Aspinall <da@inf.ed.ac.uk>1999-10-21 16:37:43 +0000
commit484cffdfbc4e1385e35d53eda5613ce2e3b3631c (patch)
tree6d086e6b34ef34980c439151e54a1527450d4e45
parentebd83a0749175afd6fc43623ece065d6b939ee3f (diff)
Changed name of proof-shell-cd-cmd for uniformity.
-rw-r--r--doc/ProofGeneral.texi4
-rw-r--r--generic/proof-config.el2
-rw-r--r--generic/proof-script.el10
-rw-r--r--isa/isa.el2
-rw-r--r--isar/isar.el2
-rw-r--r--lego/lego.el2
-rw-r--r--plastic/plastic.el2
7 files changed, 12 insertions, 12 deletions
diff --git a/doc/ProofGeneral.texi b/doc/ProofGeneral.texi
index 32625cd1..a070cd7b 100644
--- a/doc/ProofGeneral.texi
+++ b/doc/ProofGeneral.texi
@@ -2831,8 +2831,8 @@ The @code{proof-terminal-char} is added on to the end.
A command to quit the proof process. If nil, send EOF instead.@*
The @code{proof-terminal-char} is added on to the end.
@end defvar
-@c TEXI DOCSTRING MAGIC: proof-shell-cd
-@defvar proof-shell-cd
+@c TEXI DOCSTRING MAGIC: proof-shell-cd-cmd
+@defvar proof-shell-cd-cmd
Command to the proof assistant to change the working directory.@*
The format character %s is replaced with the directory, and the
@code{proof-terminal-char} is added on to the end.
diff --git a/generic/proof-config.el b/generic/proof-config.el
index f89d58cf..a2c34b59 100644
--- a/generic/proof-config.el
+++ b/generic/proof-config.el
@@ -909,7 +909,7 @@ The proof-terminal-char is added on to the end."
:type '(choice string (const nil))
:group 'proof-shell)
-(defcustom proof-shell-cd nil
+(defcustom proof-shell-cd-cmd nil
"Command to the proof assistant to change the working directory.
The format character %s is replaced with the directory, and the
proof-terminal-char is added on to the end.
diff --git a/isa/isa.el b/isa/isa.el
index 372dd7a9..7a36f967 100644
--- a/isa/isa.el
+++ b/isa/isa.el
@@ -161,7 +161,7 @@ no regular or easily discernable structure."
proof-shell-prompt-pattern "^2?[-=#>]>? *"
;; for issuing command, not used to track cwd in any way.
- proof-shell-cd "cd \"%s\""
+ proof-shell-cd-cmd "cd \"%s\""
;; FIXME: the next two are probably only good for NJ/SML
proof-shell-error-regexp "^.*Error:\\|^\364\\*\\*\\*\\|^uncaught exception "
diff --git a/isar/isar.el b/isar/isar.el
index d6ad5c56..5a652a7d 100644
--- a/isar/isar.el
+++ b/isar/isar.el
@@ -230,7 +230,7 @@
proof-shell-prompt-pattern "^\\w*[>#] "
;; for issuing command, not used to track cwd in any way.
- proof-shell-cd "cd \"%s\""
+ proof-shell-cd-cmd "cd \"%s\""
proof-shell-proof-completed-regexp nil ; n.a.
proof-shell-interrupt-regexp "\364\\*\\*\\* Interrupt\\|\360Interrupt"
diff --git a/lego/lego.el b/lego/lego.el
index 603b19d5..1f907641 100644
--- a/lego/lego.el
+++ b/lego/lego.el
@@ -441,7 +441,7 @@ We assume that module identifiers coincide with file names."
(defun lego-shell-mode-config ()
(setq proof-shell-prompt-pattern lego-shell-prompt-pattern
- proof-shell-cd lego-shell-cd
+ proof-shell-cd-cmd lego-shell-cd
proof-shell-abort-goal-regexp lego-shell-abort-goal-regexp
proof-shell-proof-completed-regexp lego-shell-proof-completed-regexp
proof-shell-error-regexp lego-error-regexp
diff --git a/plastic/plastic.el b/plastic/plastic.el
index 2c3e44ef..2bb24513 100644
--- a/plastic/plastic.el
+++ b/plastic/plastic.el
@@ -511,7 +511,7 @@ We assume that module identifiers coincide with file names."
(defun plastic-shell-mode-config ()
(setq proof-shell-prompt-pattern plastic-shell-prompt-pattern
- proof-shell-cd plastic-shell-cd
+ proof-shell-cd-cmd plastic-shell-cd
proof-shell-abort-goal-regexp plastic-shell-abort-goal-regexp
proof-shell-proof-completed-regexp plastic-shell-proof-completed-regexp
proof-shell-error-regexp plastic-error-regexp
diff --git a/generic/proof-script.el b/generic/proof-script.el
index abc77671..4b84afc3 100644
--- a/generic/proof-script.el
+++ b/generic/proof-script.el
@@ -1744,18 +1744,18 @@ Typically, a list of syntax of commands available."
proof-info-command)
(proof-define-assistant-command proof-cd
"Change directory to the default directory for the current buffer."
- proof-shell-cd
- (format proof-shell-cd
+ proof-shell-cd-cmd
+ (format proof-shell-cd-cmd
;; Use expand-file-name to avoid problems with dumb
;; proof assistants and "~"
(expand-file-name (default-directory))))
(defun proof-cd-sync ()
- "If proof-shell-cd is set, do proof-cd and wait for prover ready.
+ "If proof-shell-cd-cmd is set, do proof-cd and wait for prover ready.
This is intended as a value for proof-activate-scripting-hook"
;; The hook is set in proof-mode before proof-shell-cd may be set,
;; so we explicitly test it here.
- (if proof-shell-cd
+ (if proof-shell-cd-cmd
(progn
(proof-cd)
(proof-shell-wait))))
@@ -1744,18 +1744,18 @@ Typically, a list of syntax of commands available."
This is intended as a value for proof-activate-scripting-hook"
- ;; The hook is set in proof-mode before proof-shell-cd may be set,
+ ;; The hook is set in proof-mode before proof-shell-cd-cmd may be set,
;; so we explicitly test it here.